#ifndef DISKDUMPCMN_H
#define DISKDUMPCMN_H

/* $Id: diskdumpcmn.h,v 1.20 2006/12/06 17:42:10 akira Exp $ */

#define DUMP_PARTITION_SIGNATURE	"diskdump"
#define SIG_LEN	(sizeof(DUMP_PARTITION_SIGNATURE) - 1)
#define DISK_DUMP_SIGNATURE		"DISKDUMP"
#define ALREADY_SAVED_SIGNATURE		"DMPSAVED"
#define SWAP_PARTITION_SIGNATURE	"SWAPSPACE2"

#define FAILED		-1
#define SUCCEEDED	0

#define Err(x, ...)	fprintf(stderr, "%s: " x, CMD, ## __VA_ARGS__)
#define Syserr(x, ...)	fprintf(stderr, "%s: unable to " x ": %s\n",\
					CMD, ## __VA_ARGS__, strerror(errno))
#define Info(x...)	do { if (verbose) fprintf(stderr, x); } while (0)

#define _PROC_DISKDUMP	"/proc/diskdump"

#define DATE_TIME_FORMAT	"YYYY-mm-dd-HH:MM"
#define CURRENT_DATE_TIME	time(NULL)

#define min(x, y)	((x) > (y) ? (y) : (x))
#define max(x, y)	((x) > (y) ? (x) : (y))

#include <stdint.h>

typedef unsigned long long u64;

/*
 * Version number is expressed by "i.j.k".
 * i: major version number
 * j: minor version number
 * k: micro version number
 */
struct version_form {
	int	major;
	int	minor;
	int	micro;
};

void	 usage(const char *command_name)	__attribute__ ((noreturn));
void	 version(const char *command_name)	__attribute__ ((noreturn));
u64	 scan_param_proc(const char *param_name);
int	 convert_version_number(struct version_form *ver, const char *ver_str);
void	 progress_bar(const char *item, int symbol, off_t now, off_t max);
void	 progress_bar_post(const char *item, int symbol, off_t now, off_t max);
int	 execute_script(const char *script, const char *args);
int	 rm_dir(const char *path);
char	*convert_ip_addr(uint32_t ip);
bool	 is_swapon(void);
int	 is_mounted(const char *device_name);
int	 is_block_device(const char *device_name);
char	*get_date_time_str(const time_t);
int	 diff_days(time_t, time_t );
bool	 same_file(const char *src, const char *dst);
bool	 does_exist(const char *file);
bool	 dump_signature_is_good(const void *signature);
bool	 part_signature_is_good(const void *signature);
bool	 swap_signature_is_good(const void *signature);
char	*kernel_path(const char *kernel);

#endif
